# Changelog

All notable changes to this project will be documented in this file.

## [0.1.1] - 2024-07-21

### ⚙️ Miscellaneous Tasks

- Drop support for python 3.8 and x86 (32-bit) (#24)

## [0.1.0] - 2024-07-20

### 🐛 Bug Fixes

- Fix bugs in semigroup constructors (#11)
- Allow interrupting computation from Python with ctrl+c (#9)

### ⚙️ Miscellaneous Tasks

- Added cliff.toml
- Repo-review fixes (#6)
- Build and test on Windows (#7)
- Update pre-commit hooks (#10)
- Update pre-commit hooks (#13)
- Update pre-commit hooks (#15)
- Update pre-commit hooks (#19)
- Update pre-commit hooks (#20)
- [**breaking**] Miscellaneous cleanup (#16)
- Fixed failing tests due to rug bug (#22)

## [0.0.2] - 2024-05-22

### 🐛 Bug Fixes

- Fixed computation of distance between curves
- Added missing sign

### 📚 Documentation

- Added some more shields to the readme

### 🧪 Testing

- Added test with threefold with larger h11

### ⚙️ Miscellaneous Tasks

- Format code
- Clippy fixes
- Added repo url to toml files
- Added cliff.toml

## [0.0.1] - 2024-05-19

### 🚀 Features

- Initial commit
- Added factorials module
- Added semigroup module
- Added cache module
- Added polynomial module
- Added more constructors for semigroups
- Added pretty print polynomials
- Re-export main structs at the root
- Added misc module
- Added fundamental_period module
- Added instanton module
- Added clear function to polynomials
- Added series_inversion module
- Added hkty module
- Added python wrapper

### 🐛 Bug Fixes

- Fixed cloning, power, and reciprocal functions of polynomials
- Fixed some polynomial functions and added more tests
- Made FundamentalPeriod fields public
- Fixed small issues
- Fixed wrong values for the number of indices of instanton corrections
- Fixed typo in trait implementation
- Fixed a couple of things not being computed properly

### 🚜 Refactor

- Renamed cache to pool
- Cleaned up trait requirements by using a supertrait

### 📚 Documentation

- Small readme fixes
- Updated warning message
- Small documentation improvements

### 🧪 Testing

- Added integration tests

### ⚙️ Miscellaneous Tasks

- Renamed factorial module for consistency
- Added CI
- Added dependabot
- Renamed project
- Switch to dual license
- Apply clippy suggestions
- Renamed pool test for consistency
- Minor cleanup
- Apply clippy suggestions
- Removed binaries for now
- Updated .gitignore
- Build and test crate on multiple OSs
- Test Python package
- Added deploy workflow

<!-- generated by git-cliff -->
